@@ -39,7 +39,7 @@ def get_languages():
         cuneiform = ipc.Subprocess(['cuneiform', '-l'],
             stdout=ipc.PIPE,
             stderr=ipc.PIPE,
-            env=dict(LC_ALL='C', LANG='C')
+            env={}, # locale=POSIX
         )
     except OSError:
         raise errors.UnknownLanguageList
@@ -68,6 +68,7 @@ def recognize(pbm_file, language):
     worker = ipc.Subprocess(
         ['cuneiform', '-l', language, '-f', 'hocr', '-o', hocr_file.name, pbm_file.name],
         stdout=ipc.PIPE,
+        env={}, # locale=POSIX
     )
     worker.wait()
     return hocr_file
